pub enum AnnotatedMoveValue {
U8(u8),
U64(u64),
U128(u128),
Bool(bool),
Address(AccountAddress),
Vector(TypeTag, Vec<AnnotatedMoveValue>),
Bytes(Vec<u8>),
Struct(AnnotatedMoveStruct),
}Expand description
AnnotatedMoveValue is a fully expanded version of on chain Move data. This should only be used for debugging/client purpose right now and just for a better visualization of on chain data. In the long run, we would like to transform this struct to a Json value so that we can have a cross platform interpretation of the on chain data.
Variants
U8(u8)
U64(u64)
U128(u128)
Bool(bool)
Address(AccountAddress)
Vector(TypeTag, Vec<AnnotatedMoveValue>)
Bytes(Vec<u8>)
Struct(AnnotatedMoveStruct)
Implementations